# Link default da API
.API_LINK <- "https://dadosabertos.camara.leg.br"

# Mensagens de erro
.ERRO_RETORNO_JSON <- "API did not return json"

# Paths
.PROPOSICOES_PATH <- "/api/v2/proposicoes"
.VOTACOES_PATH <- "/api/v2/votacoes"
.DEPUTADOS_PATH <- "/api/v2/deputados"
.TIPOS_PROPOSICOES_PATH <- "/api/v2/referencias/tiposProposicao"

# Link do repositório do rcongresso
.RCONGRESSO_LINK <- "https://github.com/analytics-ufcg/rcongresso"

# Regex Pattern
.REGEX_PATTERN <- "(?=[A-Z][^A-Z])"

# Requests
.MAX_ITENS <- 100
